@@ -4,17 +4,14 @@
 import os
 os.putenv("OPENBLAS_NUM_THREADS", "1")
 
-
 try:
     profile
 except:
     profile = lambda x: x
 
-
 from pyprophet import PyProphet
-from config    import standard_config
-import sys
-
+from config    import standard_config, fix_config_types
+import sys, time
 
 def print_help():
     print
@@ -23,15 +20,16 @@ def print_help():
     print "       %s [options] input_file" % script
     print "   or "
     print "       %s --help" % script
-    config = standard_config()
-    dump_config_info(config)
+    config, info = standard_config()
+    dump_config_info(config, info)
 
-def dump_config_info(config):
+def dump_config_info(config, info):
     print
     print "parameters:"
     print
     for k, v in sorted(config.items()):
-        print "    --%-40s   default: %s" % (k,v)
+        comment = info.get(k, "")
+        print "    --%-40s   default: %-5r %s" % (k,v, comment)
     print
 
 def dump_config(config):
@@ -39,7 +37,7 @@ def dump_config(config):
     print "used parameters:"
     print
     for k, v in sorted(config.items()):
-        print "    %-40s   : %s" % (k,v)
+        print "    %-40s   : %r" % (k,v)
     print
 
 def main():
@@ -67,22 +65,19 @@ def main():
                 raise Exception("duplicate input file argument")
             path = arg
 
-    delim_in = options.get("delim.in", ",")
-    if delim_in == "tab":
-        delim_in = "\t"
-
-    delim_out = options.get("delim.out", ",")
-    if delim_out == "tab":
-        delim_out = "\t"
 
     if path is None:
         print_help()
         raise Exception("no input file given")
 
-    config = standard_config()
+    config, info = standard_config()
     config.update(options)
+    fix_config_types(config)
     dump_config(config)
 
+    delim_in = config.get("delim.in", ",")
+    delim_out = config.get("delim.out", ",")
+
     dirname = config.get("target.dir", None)
     if dirname is None:
         dirname = os.path.dirname(path)
@@ -104,9 +99,12 @@ def main():
             print
             return
 
+    start_at = time.time()
     summ_stat, final_stat, scored_table  = PyProphet().process_csv(path,
                                                                    delim_in,
                                                                    config)
+    needed = time.time() - start_at
+
     print
     print "="*78
     print
@@ -123,5 +121,16 @@ def main():
     print "WRITTEN: ", scored_table_path
     print
 
+    seconds = int(needed)
+    msecs  =  int(1000*(needed-seconds))
+    minutes = int(needed/60.0)
+
+    print "NEEDED",
+    if minutes:
+        print minutes, "minutes and",
+
+    print "%d seconds and %d msecs wall time" % (seconds, msecs)
+    print
+
 
 
